What is ecal?
-------------

``ecal`` A package for getting a US equity earnings announcement calendar.

For more documentation, please see http://be-earnings-calendar.readthedocs.io.

Installation
------------

``ecal`` can be easily installed with pip::

    $ pip install ecal
